@@ -63,8 +63,8 @@ void MingwGenerator::FrameChanged()
 {
     QString modPath = GetModulePath();
     bool existsSymbol = false;
-    TSymbolsMap::const_iterator i = m_symbolsMap.find(modPath);
-    if (i == m_symbolsMap.end())
+    TSymbolsMap::const_iterator i = m_symbolsMap.constFind(modPath);
+    if (i == m_symbolsMap.cend())
     {
         return;
     }
@@ -133,7 +133,7 @@ void MingwGenerator::LoadSymbol(const QString& module, DWORD64 dwBaseAddr)
     QString symbolType;
     do
     {
-        bfd* abfd = bfd_openr(symbolFile.toLatin1(), NULL);
+        bfd* abfd = bfd_openr(symbolFile.toLatin1().data(), NULL);
         if (abfd == NULL)
         {
             symbolType = QString::fromLatin1("no symbols loaded");
